@@ -16,8 +16,8 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef ELFBINARYINFO_20061122_H_
-#define ELFBINARYINFO_20061122_H_
+#ifndef BINARY_INFO_H_20061122_
+#define BINARY_INFO_H_20061122_
 
 #include "IPlugin.h"
 #include "ISymbolGenerator.h"
@@ -30,32 +30,30 @@ namespace BinaryInfoPlugin {
 class BinaryInfo : public QObject, public IPlugin, public ISymbolGenerator {
 	Q_OBJECT
 	Q_INTERFACES(IPlugin)
-#if QT_VERSION >= 0x050000
 	Q_PLUGIN_METADATA(IID "edb.IPlugin/1.0")
-#endif
 	Q_CLASSINFO("author", "Evan Teran")
 	Q_CLASSINFO("url", "http://www.codef00.com")
 
 public:
-	BinaryInfo();
+	explicit BinaryInfo(QObject *parent = nullptr);
 
 private:
-	virtual void private_init() override;
-	virtual QWidget* options_page() override;
+	void privateInit() override;
+	QWidget *optionsPage() override;
 
 public:
-	virtual QMenu *menu(QWidget *parent = 0) override;
-	virtual QString extra_arguments() const override;
-	virtual ArgumentStatus parse_arguments(QStringList &args) override;
+	QMenu *menu(QWidget *parent = nullptr) override;
+	QString extraArguments() const override;
+	ArgumentStatus parseArguments(QStringList &args) override;
 
 public:
-	virtual bool generate_symbol_file(const QString &filename, const QString &symbol_file) override;
+	bool generateSymbolFile(const QString &filename, const QString &symbol_file) override;
 
 public Q_SLOTS:
-	void explore_header();
+	void exploreHeader();
 
 private:
-	QMenu *menu_;
+	QMenu *menu_ = nullptr;
 };
 
 }
