@@ -42,18 +42,20 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <sys/wait.h>
 #include <unistd.h>
 
-namespace DebuggerCore {
+namespace DebuggerCorePlugin {
 
 namespace {
 
+constexpr uint64_t PageSize = 0x1000;
+
 void SET_OK(bool &ok, long value) {
 	ok = (value != -1) || (errno == 0);
 }
 
 int resume_code(int status) {
-	if(WIFSIGNALED(status)) {
+	if (WIFSIGNALED(status)) {
 		return WTERMSIG(status);
-	} else if(WIFSTOPPED(status)) {
+	} else if (WIFSTOPPED(status)) {
 		return WSTOPSIG(status);
 	}
 	return 0;
@@ -70,7 +72,7 @@ DebuggerCore::DebuggerCore() {
 #elif defined(_SC_PAGE_SIZE)
 	page_size_ = sysconf(_SC_PAGE_SIZE);
 #else
-	page_size_ = PAGE_SIZE;
+	page_size_ = PageSize;
 #endif
 }
 
@@ -79,6 +81,7 @@ DebuggerCore::DebuggerCore() {
 // Desc:
 //------------------------------------------------------------------------------
 bool DebuggerCore::has_extension(quint64 ext) const {
+	Q_UNUSED(ext)
 	return false;
 }
 
@@ -86,7 +89,7 @@ bool DebuggerCore::has_extension(quint64 ext) const {
 // Name: page_size
 // Desc: returns the size of a page on this system
 //------------------------------------------------------------------------------
-edb::address_t DebuggerCore::page_size() const {
+size_t DebuggerCore::page_size() const {
 	return page_size_;
 }
 
@@ -104,22 +107,22 @@ DebuggerCore::~DebuggerCore() {
 //      it will return false if an error or timeout occurs
 //------------------------------------------------------------------------------
 std::shared_ptr<const IDebugEvent> DebuggerCore::wait_debug_event(int msecs) {
-	if(attached()) {
+	if (attached()) {
 		int status;
 		bool timeout;
 
-		const edb::tid_t tid = native::waitpid_timeout(pid(), &status, 0, msecs, &timeout);
-		if(!timeout) {
-			if(tid > 0) {
+		const edb::tid_t tid = Posix::waitpid_timeout(pid(), &status, 0, msecs, &timeout);
+		if (!timeout) {
+			if (tid > 0) {
 
 				// normal event
-				auto e = std::make_shared<PlatformEvent>();
+				auto e    = std::make_shared<PlatformEvent>();
 				e->pid    = pid();
 				e->tid    = tid;
 				e->status = status;
 
 				char errbuf[_POSIX2_LINE_MAX];
-				if(kvm_t *const kd = kvm_openfiles(NULL, NULL, NULL, O_RDONLY, errbuf)) {
+				if (kvm_t *const kd = kvm_openfiles(NULL, NULL, NULL, O_RDONLY, errbuf)) {
 					int rc;
 					struct kinfo_proc *const proc = kvm_getprocs(kd, KERN_PROC_PID, pid(), &rc);
 
@@ -158,8 +161,8 @@ std::shared_ptr<const IDebugEvent> DebuggerCore::wait_debug_event(int msecs) {
 long DebuggerCore::read_data(edb::address_t address, bool *ok) {
 
 	Q_ASSERT(ok);
-	errno = 0;
-	const long v = ptrace(PT_READ_D, pid(), reinterpret_cast<char*>(address), 0);
+	errno        = 0;
+	const long v = ptrace(PT_READ_D, pid(), reinterpret_cast<char *>(address), 0);
 	SET_OK(*ok, v);
 	return v;
 }
@@ -169,7 +172,7 @@ long DebuggerCore::read_data(edb::address_t address, bool *ok) {
 // Desc:
 //------------------------------------------------------------------------------
 bool DebuggerCore::write_data(edb::address_t address, long value) {
-	return ptrace(PT_WRITE_D, pid(), reinterpret_cast<char*>(address), value) != -1;
+	return ptrace(PT_WRITE_D, pid(), reinterpret_cast<char *>(address), value) != -1;
 }
 
 //------------------------------------------------------------------------------
@@ -180,7 +183,7 @@ bool DebuggerCore::attach(edb::pid_t pid) {
 	detach();
 
 	const long ret = ptrace(PT_ATTACH, pid, 0, 0);
-	if(ret == 0) {
+	if (ret == 0) {
 		pid_           = pid;
 		active_thread_ = pid;
 		threads_.clear();
@@ -197,12 +200,12 @@ bool DebuggerCore::attach(edb::pid_t pid) {
 // Desc:
 //------------------------------------------------------------------------------
 void DebuggerCore::detach() {
-	if(attached()) {
+	if (attached()) {
 
 		// TODO: do i need to stop each thread first, and wait for them?
 
 		clear_breakpoints();
-		for(auto it = threads_.begin(); it != threads_.end(); ++it) {
+		for (auto it = threads_.begin(); it != threads_.end(); ++it) {
 			ptrace(PT_DETACH, it.key(), 0, 0);
 		}
 
@@ -216,10 +219,10 @@ void DebuggerCore::detach() {
 // Desc:
 //------------------------------------------------------------------------------
 void DebuggerCore::kill() {
-	if(attached()) {
+	if (attached()) {
 		clear_breakpoints();
 		ptrace(PT_KILL, pid(), 0, 0);
-		native::waitpid(pid(), 0, WAIT_ANY);
+		Posix::waitpid(pid(), 0, WAIT_ANY);
 		pid_ = 0;
 		threads_.clear();
 	}
@@ -230,8 +233,8 @@ void DebuggerCore::kill() {
 // Desc: stops *all* threads of a process
 //------------------------------------------------------------------------------
 void DebuggerCore::pause() {
-	if(attached()) {
-		for(auto it = threads_.begin(); it != threads_.end(); ++it) {
+	if (attached()) {
+		for (auto it = threads_.begin(); it != threads_.end(); ++it) {
 			::kill(it.key(), SIGSTOP);
 		}
 	}
@@ -244,73 +247,15 @@ void DebuggerCore::pause() {
 void DebuggerCore::resume(edb::EVENT_STATUS status) {
 	// TODO: assert that we are paused
 
-	if(attached()) {
-		if(status != edb::DEBUG_STOP) {
+	if (attached()) {
+		if (status != edb::DEBUG_STOP) {
 			const edb::tid_t tid = active_thread();
-			const int code = (status == edb::DEBUG_EXCEPTION_NOT_HANDLED) ? resume_code(threads_[tid].status) : 0;
+			const int code       = (status == edb::DEBUG_EXCEPTION_NOT_HANDLED) ? resume_code(threads_[tid].status) : 0;
 			ptrace(PT_CONTINUE, tid, reinterpret_cast<caddr_t>(1), code);
 		}
 	}
 }
 
-//------------------------------------------------------------------------------
-// Name: step
-// Desc:
-//------------------------------------------------------------------------------
-void DebuggerCore::step(edb::EVENT_STATUS status) {
-	// TODO: assert that we are paused
-
-	if(attached()) {
-		if(status != edb::DEBUG_STOP) {
-			const edb::tid_t tid = active_thread();
-			const int code = (status == edb::DEBUG_EXCEPTION_NOT_HANDLED) ? resume_code(threads_[tid].status) : 0;
-			ptrace(PT_STEP, tid, reinterpret_cast<caddr_t>(1), code);
-		}
-	}
-}
-
-//------------------------------------------------------------------------------
-// Name: get_state
-// Desc:
-//------------------------------------------------------------------------------
-void DebuggerCore::get_state(State *state) {
-
-	Q_ASSERT(state);
-
-	// TODO: assert that we are paused
-
-	auto state_impl = static_cast<PlatformState *>(state->impl_);
-
-	if(attached()) {
-	#if defined(EDB_X86)
-		if(ptrace(PT_GETREGS, active_thread(), reinterpret_cast<char*>(&state_impl->regs_), 0) != -1) {
-			state_impl->gs_base = 0;
-			state_impl->fs_base = 0;
-		}
-	#endif
-		// TODO implement this
-	} else {
-		state->clear();
-	}
-}
-
-//------------------------------------------------------------------------------
-// Name: set_state
-// Desc:
-//------------------------------------------------------------------------------
-void DebuggerCore::set_state(const State &state) {
-
-	// TODO: assert that we are paused
-
-	auto state_impl = static_cast<PlatformState *>(state.impl_);
-
-	if(attached()) {
-		ptrace(PT_SETREGS, active_thread(), reinterpret_cast<char*>(&state_impl->regs_), 0);
-		// TODO: FPU
-		// TODO: Debug Registers
-	}
-}
-
 //------------------------------------------------------------------------------
 // Name: open
 // Desc:
@@ -319,7 +264,7 @@ bool DebuggerCore::open(const QString &path, const QString &cwd, const QList<QBy
 	detach();
 	pid_t pid;
 
-	switch(pid = fork()) {
+	switch (pid = fork()) {
 	case 0:
 		// we are in the child now...
 
@@ -327,14 +272,14 @@ bool DebuggerCore::open(const QString &path, const QString &cwd, const QList<QBy
 		ptrace(PT_TRACE_ME, 0, 0, 0);
 
 		// redirect it's I/O
-		if(!tty.isEmpty()) {
+		if (!tty.isEmpty()) {
 			FILE *const std_out = freopen(qPrintable(tty), "r+b", stdout);
 			FILE *const std_in  = freopen(qPrintable(tty), "r+b", stdin);
 			FILE *const std_err = freopen(qPrintable(tty), "r+b", stderr);
 
-			Q_UNUSED(std_out);
-			Q_UNUSED(std_in);
-			Q_UNUSED(std_err);
+			Q_UNUSED(std_out)
+			Q_UNUSED(std_in)
+			Q_UNUSED(std_err)
 		}
 
 		// do the actual exec
@@ -353,12 +298,12 @@ bool DebuggerCore::open(const QString &path, const QString &cwd, const QList<QBy
 			threads_.clear();
 
 			int status;
-			if(native::waitpid(pid, &status, 0) == -1) {
+			if (Posix::waitpid(pid, &status, 0) == -1) {
 				return false;
 			}
 
 			// the very first event should be a STOP of type SIGTRAP
-			if(!WIFSTOPPED(status) || WSTOPSIG(status) != SIGTRAP) {
+			if (!WIFSTOPPED(status) || WSTOPSIG(status) != SIGTRAP) {
 				detach();
 				return false;
 			}
@@ -369,7 +314,7 @@ bool DebuggerCore::open(const QString &path, const QString &cwd, const QList<QBy
 			active_thread_       = pid;
 			threads_[pid].status = status;
 			return true;
-		} while(0);
+		} while (0);
 		break;
 	}
 }
@@ -387,8 +332,8 @@ void DebuggerCore::set_active_thread(edb::tid_t tid) {
 // Name: create_state
 // Desc:
 //------------------------------------------------------------------------------
-IState *DebuggerCore::create_state() const {
-	return new PlatformState;
+std::unique_ptr<IState> DebuggerCore::create_state() const {
+	return std::make_unique<PlatformState>();
 }
 
 //------------------------------------------------------------------------------
@@ -400,14 +345,14 @@ QMap<edb::pid_t, ProcessInfo> DebuggerCore::enumerate_processes() const {
 
 	char ebuffer[_POSIX2_LINE_MAX];
 	int numprocs;
-	if(kvm_t *const kaccess = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, 0, O_RDONLY, ebuffer)) {
-		if(struct kinfo_proc *const kprocaccess = kvm_getprocs(kaccess, KERN_PROC_ALL, 0, &numprocs)) {
-			for(int i = 0; i < numprocs; ++i) {
+	if (kvm_t *const kaccess = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, 0, O_RDONLY, ebuffer)) {
+		if (struct kinfo_proc *const kprocaccess = kvm_getprocs(kaccess, KERN_PROC_ALL, 0, &numprocs)) {
+			for (int i = 0; i < numprocs; ++i) {
 				ProcessInfo procInfo;
 
-				procInfo.pid   = kprocaccess[i].ki_pid;
-				procInfo.uid   = kprocaccess[i].ki_uid;
-				procInfo.name  = kprocaccess[i].ki_comm;
+				procInfo.pid  = kprocaccess[i].ki_pid;
+				procInfo.uid  = kprocaccess[i].ki_uid;
+				procInfo.name = kprocaccess[i].ki_comm;
 				ret.insert(procInfo.pid, procInfo);
 			}
 		}
@@ -419,24 +364,6 @@ QMap<edb::pid_t, ProcessInfo> DebuggerCore::enumerate_processes() const {
 	return ret;
 }
 
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QString DebuggerCore::process_exe(edb::pid_t pid) const {
-	// TODO: implement this
-	return QString();
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QString DebuggerCore::process_cwd(edb::pid_t pid) const {
-	// TODO: implement this
-	return QString();
-}
-
 //------------------------------------------------------------------------------
 // Name:
 // Desc:
@@ -446,87 +373,6 @@ edb::pid_t DebuggerCore::parent_pid(edb::pid_t pid) const {
 	return -1;
 }
 
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QList<std::shared_ptr<IRegion>> DebuggerCore::memory_regions() const {
-	QList<std::shared_ptr<IRegion>> regions;
-
-	if(pid_ != 0) {
-		char buffer[PATH_MAX] = {};
-		struct ptrace_vm_entry vm_entry;
-		memset(&vm_entry, 0, sizeof(vm_entry));
-		vm_entry.pve_entry = 0;
-
-		while(ptrace(PT_VM_ENTRY, pid_, reinterpret_cast<char*>(&vm_entry), NULL) == 0) {
-			vm_entry.pve_path    = buffer;
-			vm_entry.pve_pathlen = sizeof(buffer);
-
-			const edb::address_t start               = vm_entry.pve_start;
-			const edb::address_t end                 = vm_entry.pve_end;
-			const edb::address_t base                = vm_entry.pve_start - vm_entry.pve_offset;
-			const QString name                       = vm_entry.pve_path;
-			const IRegion::permissions_t permissions = vm_entry.pve_prot;
-
-			regions.push_back(std::make_shared<PlatformRegion>(start, end, base, name, permissions));
-			memset(buffer, 0, sizeof(buffer));
-		}
-	}
-
-	return regions;
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QList<QByteArray> DebuggerCore::process_args(edb::pid_t pid) const {
-	QList<QByteArray> ret;
-	if(pid != 0) {
-		// TODO: assert attached!
-	}
-	return ret;
-
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-edb::address_t DebuggerCore::process_code_address() const {
-	qDebug() << "TODO: implement DebuggerCore::process_code_address";
-	return 0;
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-edb::address_t DebuggerCore::process_data_address() const {
-	qDebug() << "TODO: implement DebuggerCore::process_data_address";
-	return 0;
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QList<Module> DebuggerCore::loaded_modules() const {
-    QList<Module> modules;
-	qDebug() << "TODO: implement DebuggerCore::loaded_modules";
-    return modules;
-}
-
-//------------------------------------------------------------------------------
-// Name:
-// Desc:
-//------------------------------------------------------------------------------
-QDateTime DebuggerCore::process_start(edb::pid_t pid) const {
-	qDebug() << "TODO: implement DebuggerCore::process_start";
-	return QDateTime();
-}
-
 //------------------------------------------------------------------------------
 // Name:
 // Desc:
@@ -589,8 +435,4 @@ QString DebuggerCore::instruction_pointer() const {
 #endif
 }
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(DebuggerCore, DebuggerCore)
-#endif
-
 }
